@@ -13,6 +13,7 @@ predict.spglm <- function(object, newdata, type = c("link", "response"), se.fit
                           newdata_size, level = 0.95, local, var_correct = TRUE, ...) {
 
 
+
   # match type argument so the two display
   type <- match.arg(type)
 
@@ -147,70 +148,117 @@ predict.spglm <- function(object, newdata, type = c("link", "response"), se.fit
     # local prediction list
     local_list <- get_local_list_prediction(local)
 
-    # random stuff
-    if (!is.null(object$random)) {
-      randcov_names <- get_randcov_names(object$random)
-      randcov_Zs <- get_randcov_Zs(obdata, randcov_names)
-      # comment out here for simple
-      reform_bar_list <- lapply(randcov_names, function(randcov_name) {
-        bar_split <- unlist(strsplit(randcov_name, " | ", fixed = TRUE))
-        reform_bar2 <- reformulate(bar_split[[2]], intercept = FALSE)
-        if (bar_split[[1]] != "1") {
-          reform_bar1 <- reformulate(bar_split[[1]], intercept = FALSE)
-        } else {
-          reform_bar1 <- NULL
-        }
-        list(reform_bar2 = reform_bar2, reform_bar1 = reform_bar1)
-      })
-      reform_bar2_list <- lapply(reform_bar_list, function(x) x$reform_bar2)
-      names(reform_bar2_list) <- randcov_names
-      reform_bar1_list <- lapply(reform_bar_list, function(x) x$reform_bar1)
-      names(reform_bar1_list) <- randcov_names
-      Z_index_obdata_list <- lapply(reform_bar2_list, function(reform_bar2) {
-        reform_bar2_mf <- model.frame(reform_bar2, obdata)
-        reform_bar2_terms <- terms(reform_bar2_mf)
-        reform_bar2_xlev <- .getXlevels(reform_bar2_terms, reform_bar2_mf)
-        reform_bar2_mx <- model.matrix(reform_bar2, obdata)
-        reform_bar2_names <- colnames(reform_bar2_mx)
-        reform_bar2_split <- split(reform_bar2_mx, seq_len(NROW(reform_bar2_mx)))
-        reform_bar2_vals <- reform_bar2_names[vapply(reform_bar2_split, function(y) which(as.logical(y)), numeric(1))]
-        list(reform_bar2_vals = reform_bar2_vals, reform_bar2_xlev = reform_bar2_xlev)
-      })
-      # Z_index_obdata_list <- lapply(reform_bar2_list, function(reform_bar2) as.vector(model.matrix(reform_bar2, obdata)))
-      names(Z_index_obdata_list) <- randcov_names
-      Z_val_obdata_list <- lapply(reform_bar1_list, function(reform_bar1) {
-        if (is.null(reform_bar1)) {
-          return(NULL)
-        } else {
-          return(as.vector(model.matrix(reform_bar1, obdata)))
-        }
-      })
-      names(Z_val_obdata_list) <- randcov_names
-    } else {
-      reform_bar2_list <- NULL
-      Z_index_obdata_list <- NULL
-      reform_bar1_list <- NULL
-      Z_val_obdata_list <- NULL
-    }
+    dotlist <- list(...)
+    dotlist_names <- names(dotlist)
 
-    # partition factor stuff
-    if (!is.null(object$partition_factor)) {
-      partition_factor_val <- get_partition_name(labels(terms(object$partition_factor)))
-      bar_split <- unlist(strsplit(partition_factor_val, " | ", fixed = TRUE))
-      reform_bar2 <- reformulate(bar_split[[2]], intercept = FALSE)
-      p_reform_bar2_mf <- model.frame(reform_bar2, obdata)
-      p_reform_bar2_terms <- terms(p_reform_bar2_mf)
-      p_reform_bar2_xlev <- .getXlevels(p_reform_bar2_terms, p_reform_bar2_mf)
-      p_reform_bar2_mx <- model.matrix(reform_bar2, obdata)
-      p_reform_bar2_names <- colnames(p_reform_bar2_mx)
-      p_reform_bar2_split <- split(p_reform_bar2_mx, seq_len(NROW(p_reform_bar2_mx)))
-      p_reform_bar2_vals <- p_reform_bar2_names[vapply(p_reform_bar2_split, function(y) which(as.logical(y)), numeric(1))]
-      partition_index_obdata <- list(reform_bar2_vals = p_reform_bar2_vals, reform_bar2_xlev = p_reform_bar2_xlev)
-      # partition_index_obdata <- as.vector(model.matrix(reform_bar2, obdata))
+    if ("extra_randcov_list" %in% dotlist_names && !is.null(dotlist[["extra_randcov_list"]])) {
+      extra_randcov_list <- dotlist$extra_randcov_list
     } else {
-      reform_bar2 <- NULL
-      partition_index_obdata <- NULL
+      extra_randcov_list <- get_extra_randcov_list(object, obdata, newdata)
     }
+    reform_bar2_list <- extra_randcov_list$reform_bar2_list
+    Z_index_obdata_list <- extra_randcov_list$Z_index_obdata_list
+    reform_bar1_list <- extra_randcov_list$reform_bar1_list
+    Z_val_obdata_list <- extra_randcov_list$Z_val_obdata_list
+
+    if ("extra_partition_list" %in% dotlist_names && !is.null(dotlist[["extra_partition_list"]])) {
+      extra_partition_list <- dotlist$extra_partition_list
+    } else {
+      extra_partition_list <- get_extra_partition_list(object, obdata, newdata)
+    }
+    reform_bar2 <- extra_partition_list$reform_bar2
+    partition_index_obdata <- extra_partition_list$partition_index_obdata
+
+    # # random stuff
+    # if (!is.null(object$random)) {
+    #   randcov_names <- get_randcov_names(object$random)
+    #   # this causes a memory leak and was not even needed
+    #   # randcov_Zs <- get_randcov_Zs(obdata, randcov_names)
+    #   # comment out here for simple
+    #   reform_bar_list <- lapply(randcov_names, function(randcov_name) {
+    #     bar_split <- unlist(strsplit(randcov_name, " | ", fixed = TRUE))
+    #     reform_bar2 <- reformulate(bar_split[[2]], intercept = FALSE)
+    #     if (bar_split[[1]] != "1") {
+    #       reform_bar1 <- reformulate(bar_split[[1]], intercept = FALSE)
+    #     } else {
+    #       reform_bar1 <- NULL
+    #     }
+    #     list(reform_bar2 = reform_bar2, reform_bar1 = reform_bar1)
+    #   })
+    #   reform_bar2_list <- lapply(reform_bar_list, function(x) x$reform_bar2)
+    #   names(reform_bar2_list) <- randcov_names
+    #   reform_bar1_list <- lapply(reform_bar_list, function(x) x$reform_bar1)
+    #   names(reform_bar1_list) <- randcov_names
+    #   Z_index_obdata_list <- lapply(reform_bar2_list, function(reform_bar2) {
+    #     reform_bar2_mf <- model.frame(reform_bar2, obdata)
+    #     reform_bar2_terms <- terms(reform_bar2_mf)
+    #     reform_bar2_xlev <- .getXlevels(reform_bar2_terms, reform_bar2_mf)
+    #     reform_bar2_mx <- model.matrix(reform_bar2, obdata)
+    #     reform_bar2_names <- colnames(reform_bar2_mx)
+    #     reform_bar2_split <- split(reform_bar2_mx, seq_len(NROW(reform_bar2_mx)))
+    #     reform_bar2_vals <- reform_bar2_names[vapply(reform_bar2_split, function(y) which(as.logical(y)), numeric(1))]
+    #
+    #
+    #     # adding dummy levels if newdata observations of random effects are not in original data
+    #     # terms object is unchanged if levels change
+    #     # reform_bar2_mf_new <- model.frame(reform_bar2, newdata)
+    #     # reform_bar2_mf_full <- model.frame(reform_bar2, merge(obdata, newdata, all = TRUE))
+    #     # reform_bar2_terms_full <- terms(rbind(reform_bar2_mf, reform_bar2_mf_new))
+    #     reform_bar2_xlev_full <- .getXlevels(reform_bar2_terms, rbind(reform_bar2_mf, model.frame(reform_bar2, newdata)))
+    #     if (!identical(reform_bar2_xlev, reform_bar2_xlev_full)) {
+    #       reform_bar2_xlev <- reform_bar2_xlev_full
+    #     }
+    #
+    #
+    #     list(reform_bar2_vals = reform_bar2_vals, reform_bar2_xlev = reform_bar2_xlev)
+    #   })
+    #   # Z_index_obdata_list <- lapply(reform_bar2_list, function(reform_bar2) as.vector(model.matrix(reform_bar2, obdata)))
+    #   names(Z_index_obdata_list) <- randcov_names
+    #   Z_val_obdata_list <- lapply(reform_bar1_list, function(reform_bar1) {
+    #     if (is.null(reform_bar1)) {
+    #       return(NULL)
+    #     } else {
+    #       return(as.vector(model.matrix(reform_bar1, obdata)))
+    #     }
+    #   })
+    #   names(Z_val_obdata_list) <- randcov_names
+    # } else {
+    #   reform_bar2_list <- NULL
+    #   Z_index_obdata_list <- NULL
+    #   reform_bar1_list <- NULL
+    #   Z_val_obdata_list <- NULL
+    # }
+    #
+    # # partition factor stuff
+    # if (!is.null(object$partition_factor)) {
+    #   partition_factor_val <- get_partition_name(labels(terms(object$partition_factor)))
+    #   bar_split <- unlist(strsplit(partition_factor_val, " | ", fixed = TRUE))
+    #   reform_bar2 <- reformulate(bar_split[[2]], intercept = FALSE)
+    #   p_reform_bar2_mf <- model.frame(reform_bar2, obdata)
+    #   p_reform_bar2_terms <- terms(p_reform_bar2_mf)
+    #   p_reform_bar2_xlev <- .getXlevels(p_reform_bar2_terms, p_reform_bar2_mf)
+    #   p_reform_bar2_mx <- model.matrix(reform_bar2, obdata)
+    #   p_reform_bar2_names <- colnames(p_reform_bar2_mx)
+    #   p_reform_bar2_split <- split(p_reform_bar2_mx, seq_len(NROW(p_reform_bar2_mx)))
+    #   p_reform_bar2_vals <- p_reform_bar2_names[vapply(p_reform_bar2_split, function(y) which(as.logical(y)), numeric(1))]
+    #
+    #
+    #   # adding dummy levels if newdata observations of random effects are not in original data
+    #   # terms object is unchanged if levels change
+    #   # p_reform_bar2_mf_new <- model.frame(reform_bar2, newdata)
+    #   # reform_bar2_mf_full <- model.frame(reform_bar2, merge(obdata, newdata, all = TRUE))
+    #   # p_reform_bar2_terms_full <- terms(rbind(p_reform_bar2_mf, p_reform_bar2_mf_new))
+    #   p_reform_bar2_xlev_full <- .getXlevels(p_reform_bar2_terms, rbind(p_reform_bar2_mf, model.frame(reform_bar2, newdata)))
+    #   if (!identical(p_reform_bar2_xlev, p_reform_bar2_xlev_full)) {
+    #     p_reform_bar2_xlev <- p_reform_bar2_xlev_full
+    #   }
+    #
+    #   partition_index_obdata <- list(reform_bar2_vals = p_reform_bar2_vals, reform_bar2_xlev = p_reform_bar2_xlev)
+    #   # partition_index_obdata <- as.vector(model.matrix(reform_bar2, obdata))
+    # } else {
+    #   reform_bar2 <- NULL
+    #   partition_index_obdata <- NULL
+    # }
 
     # matrix cholesky
     if (local_list$method == "all") {
@@ -234,7 +282,7 @@ predict.spglm <- function(object, newdata, type = c("link", "response"), se.fit
       cl <- parallel::makeCluster(local_list$ncores)
       pred_spglm <- parallel::parLapply(cl, newdata_list, get_pred_spglm,
         se.fit = se.fit,
-        interval = interval, formula = object$formula,
+        interval = interval, formula = object$terms,
         obdata = obdata, xcoord = xcoord, ycoord = ycoord,
         spcov_params_val = spcov_params_val, random = object$random,
         randcov_params_val = randcov_params_val,
@@ -257,7 +305,7 @@ predict.spglm <- function(object, newdata, type = c("link", "response"), se.fit
     } else {
       pred_spglm <- lapply(newdata_list, get_pred_spglm,
         se.fit = se.fit,
-        interval = interval, formula = object$formula,
+        interval = interval, formula = object$terms,
         obdata = obdata, xcoord = xcoord, ycoord = ycoord,
         spcov_params_val = spcov_params_val, random = object$random,
         randcov_params_val = randcov_params_val,
@@ -419,10 +467,16 @@ get_pred_spglm <- function(newdata_list, se.fit, interval, formula, obdata, xcoo
     partition_index_data = partition_index_obdata
   )
 
-  # subsetting partition vector
+  # subsetting partition vector (efficient but causes problems later with
+  # random effect subsetting)
   if (!is.null(partition_vector) && local$method %in% c("distance", "covariance") &&
-    !labels(terms(partition_factor)) %in% labels(terms(random))) {
-    obdata <- obdata[as.vector(partition_vector) == 1, , drop = FALSE]
+      (is.null(random) || !labels(terms(partition_factor)) %in% labels(terms(random)))) {
+    partition_index <- as.vector(partition_vector) == 1
+    Z_index_obdata_list <- lapply(Z_index_obdata_list, function(x) {
+      x$reform_bar2_vals <- x$reform_bar2_vals[partition_index]
+      x
+    })
+    obdata <- obdata[partition_index, , drop = FALSE]
     partition_vector <- Matrix(1, nrow = 1, ncol = NROW(obdata))
   }
 
@@ -435,6 +489,7 @@ get_pred_spglm <- function(newdata_list, se.fit, interval, formula, obdata, xcoo
     obdata <- obdata[nn_index, , drop = FALSE]
     dist_vector <- dist_vector[, nn_index]
     w <- w[nn_index]
+    y <- y[nn_index]
     if (!is.null(size)) {
       size <- size[nn_index]
     }
@@ -457,6 +512,7 @@ get_pred_spglm <- function(newdata_list, se.fit, interval, formula, obdata, xcoo
     obdata <- obdata[cov_index, , drop = FALSE]
     cov_vector_val <- cov_vector_val[cov_index]
     w <- w[cov_index]
+    y <- y[cov_index]
     if (!is.null(size)) {
       size <- size[cov_index]
     }
@@ -465,7 +521,8 @@ get_pred_spglm <- function(newdata_list, se.fit, interval, formula, obdata, xcoo
   if (local$method %in% c("distance", "covariance")) {
     if (!is.null(random)) {
       randcov_names <- get_randcov_names(random)
-      randcov_Zs <- get_randcov_Zs(obdata, randcov_names)
+      xlev_list <- lapply(Z_index_obdata_list, function(x) x$reform_bar2_xlev)
+      randcov_Zs <- get_randcov_Zs(obdata, randcov_names, xlev_list = xlev_list)
     }
     partition_matrix_val <- partition_matrix(partition_factor, obdata)
     cov_matrix_val <- cov_matrix(
@@ -476,18 +533,6 @@ get_pred_spglm <- function(newdata_list, se.fit, interval, formula, obdata, xcoo
     cov_lowchol <- t(Matrix::chol(Matrix::forceSymmetric(cov_matrix_val)))
     model_frame <- model.frame(formula, obdata, drop.unused.levels = TRUE, na.action = na.pass, xlev = xlevels)
     Xmat <- model.matrix(formula, model_frame, contrasts = contrasts)
-    y <- model.response(model_frame)
-    if (NCOL(y) == 2) {
-      y_modr <- y
-      y <- y_modr[, 1, drop = FALSE]
-      size <- rowSums(y_modr)
-    } else {
-      if (family == "binomial") {
-        size <- rep(1, n)
-      } else {
-        size <- NULL
-      }
-    }
   }
 
 
