@@ -73,6 +73,8 @@
 #'   when \code{W} is provided and \code{row_st} is \code{FALSE}.  When \code{M},
 #'   is required, the default is the identity matrix. \code{M} must be diagonal
 #'   or given as a vector or one-column matrix assumed to be the diagonal.
+#' @param range_positive Whether the range should be constrained to be positive.
+#'   The default is \code{TRUE}.
 #' @param ... Other arguments to [stats::optim()].
 #'
 #' @details The spatial generalized linear model for areal data
@@ -96,38 +98,38 @@
 #'
 #'   The supports for \eqn{y} for each family are given below:
 #'   \itemize{
-#'     \item{family: }{support of \eqn{y}}
-#'     \item{poisson: }{\eqn{0 \le y}; \eqn{y} an integer}
-#'     \item{nbinomial: }{\eqn{0 \le y}; \eqn{y} an integer}
-#'     \item{binomial: }{\eqn{0 \le y}; \eqn{y} an integer}
-#'     \item{beta: }{\eqn{0 < y < 1}}
-#'     \item{Gamma: }{\eqn{0 < y}}
-#'     \item{inverse.gaussian: }{\eqn{0 < y}}
+#'     \item family: support of \eqn{y}
+#'     \item poisson: \eqn{0 \le y}; \eqn{y} an integer
+#'     \item nbinomial: \eqn{0 \le y}; \eqn{y} an integer
+#'     \item binomial: \eqn{0 \le y}; \eqn{y} an integer
+#'     \item beta: \eqn{0 < y < 1}
+#'     \item Gamma: \eqn{0 < y}
+#'     \item inverse.gaussian: \eqn{0 < y}
 #'   }
 #'
 #'   The generalized linear model families
 #'   and the parameterizations of their link functions are given
 #'   below:
 #'   \itemize{
-#'     \item{family: }{link function}
-#'     \item{poisson: }{\eqn{g(\mu) = log(\eta)} (log link)}
-#'     \item{nbinomial: }{\eqn{g(\mu) = log(\eta)} (log link)}
-#'     \item{binomial: }{\eqn{g(\mu) = log(\eta / (1 - \eta))} (logit link)}
-#'     \item{beta: }{\eqn{g(\mu) = log(\eta / (1 - \eta))} (logit link)}
-#'     \item{Gamma: }{\eqn{g(\mu) = log(\eta)} (log link)}
-#'     \item{inverse.gaussian: }{\eqn{g(\mu) = log(\eta)} (log link)}
+#'     \item family: link function
+#'     \item poisson: \eqn{g(\mu) = log(\eta)} (log link)
+#'     \item nbinomial: \eqn{g(\mu) = log(\eta)} (log link)
+#'     \item binomial: \eqn{g(\mu) = log(\eta / (1 - \eta))} (logit link)
+#'     \item beta: \eqn{g(\mu) = log(\eta / (1 - \eta))} (logit link)
+#'     \item Gamma: \eqn{g(\mu) = log(\eta)} (log link)
+#'     \item inverse.gaussian: \eqn{g(\mu) = log(\eta)} (log link)
 #'   }
 #'
 #'   The variance function of an individual \eqn{y} (given \eqn{\mu})
 #'   for each generalized linear model family is given below:
 #'   \itemize{
-#'     \item{family: }{\eqn{Var(y)}}
-#'     \item{poisson: }{\eqn{\mu \phi}}
-#'     \item{nbinomial: }{\eqn{\mu + \mu^2 / \phi}}
-#'     \item{binomial: }{\eqn{n \mu (1 - \mu) \phi}}
-#'     \item{beta: }{\eqn{\mu (1 - \mu) / (1 + \phi)}}
-#'     \item{Gamma: }{\eqn{\mu^2 / \phi}}
-#'     \item{inverse.gaussian: }{\eqn{\mu^2 / \phi}}
+#'     \item family: \eqn{Var(y)}
+#'     \item poisson: \eqn{\mu \phi}
+#'     \item nbinomial: \eqn{\mu + \mu^2 / \phi}
+#'     \item binomial: \eqn{n \mu (1 - \mu) \phi}
+#'     \item beta: \eqn{\mu (1 - \mu) / (1 + \phi)}
+#'     \item Gamma: \eqn{\mu^2 / \phi}
+#'     \item inverse.gaussian: \eqn{\mu^2 / \phi}
 #'   }
 #'   The parameter \eqn{\phi} is a dispersion parameter that influences \eqn{Var(y)}.
 #'   For the \code{poisson} and \code{binomial} families, \eqn{\phi} is always
@@ -154,18 +156,18 @@
 #'
 #'   \code{spcov_type} Details: Parametric forms for \eqn{R} are given below:
 #'   \itemize{
-#'     \item{car: }{\eqn{(I - range * W)^{-1}M}, weights matrix \eqn{W},
-#'      symmetry condition matrix \eqn{M}}
-#'     \item{sar: }{\eqn{[(I - range * W)(I - range * W)^T]^{-1}},
-#'      weights matrix \eqn{W}, \eqn{^T} indicates matrix transpose}
+#'     \item car: \eqn{(I - range * W)^{-1}M}, weights matrix \eqn{W},
+#'      symmetry condition matrix \eqn{M}
+#'     \item sar: \eqn{[(I - range * W)(I - range * W)^T]^{-1}},
+#'      weights matrix \eqn{W}, \eqn{^T} indicates matrix transpose
 #'   }
 #'   If there are observations with no neighbors, they are given a unique variance
 #'   parameter called \code{extra}, which must be non-negative.
 #'
 #'  \code{estmethod} Details: The various estimation methods are
 #'   \itemize{
-#'     \item{\code{reml}: }{Maximize the restricted log-likelihood.}
-#'     \item{\code{ml}: }{Maximize the log-likelihood.}
+#'     \item \code{reml}: Maximize the restricted log-likelihood.
+#'     \item \code{ml}: Maximize the log-likelihood.
 #'   }
 #'   Note that the likelihood being optimized is obtained using the Laplace approximation.
 #'
@@ -221,7 +223,7 @@
 #' @references
 #' McCullagh P. and Nelder, J. A. (1989) \emph{Generalized Linear Models}. London: Chapman and Hall.
 spgautor <- function(formula, family, data, spcov_type, spcov_initial, dispersion_initial,
-                     estmethod = "reml", random, randcov_initial, partition_factor, W, row_st = TRUE, M, ...) {
+                     estmethod = "reml", random, randcov_initial, partition_factor, W, row_st = TRUE, M, range_positive = TRUE, ...) {
 
   # set car as default if nothing specified
   if (missing(spcov_type) && missing(spcov_initial)) {
@@ -264,6 +266,9 @@ spgautor <- function(formula, family, data, spcov_type, spcov_initial, dispersio
   if (missing(dispersion_initial)) dispersion_initial <- NULL else family <- class(dispersion_initial)
 
   # fix family
+  if (missing(family)) {
+    stop("The family argument must be specified.", call. = FALSE)
+  }
   if (is.symbol(substitute(family))) { # or is.language
     family <- deparse1(substitute(family))
   }
@@ -314,7 +319,7 @@ spgautor <- function(formula, family, data, spcov_type, spcov_initial, dispersio
   data_object <- get_data_object_spgautor(
     formula, family, data, spcov_initial,
     estmethod, W, M, random, randcov_initial,
-    partition_factor, row_st, ...
+    partition_factor, row_st, range_positive, ...
   )
 
   cov_est_object <- cov_estimate_laploglik_spgautor(data_object, formula,
